#
# spec file for package ghc-optparse-applicative
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name optparse-applicative
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.18.1.0
Release:        2.1
Summary:        Utilities and combinators for parsing command line options
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-prettyprinter-ansi-terminal-devel
BuildRequires:  ghc-prettyprinter-ansi-terminal-prof
BuildRequires:  ghc-prettyprinter-devel
BuildRequires:  ghc-prettyprinter-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
%endif

%description
Optparse-applicative is a haskell library for parsing options on the command
line, and providing a powerful applicative interface for composing them.

optparse-applicative takes care of reading and validating the arguments passed
to the command line, handling and reporting errors, generating a usage line, a
comprehensive help screen, and enabling context-sensitive bash, zsh, and fish
completions.

See the included README for detailed instructions and examples, which is also
available on github <https://github.com/pcapriotti/optparse-applicative>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Jan 12 2025 Peter Simons <psimons@suse.com>
- Update optparse-applicative to version 0.18.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue May 30 2023 Peter Simons <psimons@suse.com>
- Update optparse-applicative to version 0.18.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/optparse-applicative-0.18.1.0/src/CHANGELOG.md
* Tue May 23 2023 Peter Simons <psimons@suse.com>
- Update optparse-applicative to version 0.17.1.0.
  [#]# Version 0.17.1.0 (21 May 2023)
  - Widen bounds for `ansi-wl-pprint`. This supports the use of `prettyprinter`
    in a non-breaking way, as the `ansi-wl-pprint > 1.0` support the newer
    library.
  - Export `helpIndent` from `Options.Applicative`.
  - Export completion script generators from `Options.Applicative.BashCompletion`.
  - Add `simpleVersioner` utility for adding a '--version' option to a parser.
  - Improve documentation.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Feb  1 2022 Peter Simons <psimons@suse.com>
- Update optparse-applicative to version 0.17.0.0.
  [#]# Version 0.17.0.0 (1 Feb 2022)
  - Make tabulation width configurable in usage texts.
  - Separate program name and description in ParserHelp type.
  - Add `helperWith` function, which can be easily used to
    localize the help flag.
  - Improve usage texts when command names are long.
  - Improve Documentation.
* Sat Nov 20 2021 psimons@suse.com
- Update optparse-applicative to version 0.16.1.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Jul 27 2021 psimons@suse.com
- Update optparse-applicative to version 0.16.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Nov 23 2020 psimons@suse.com
- Update optparse-applicative to version 0.16.1.0.
  [#]# Version 0.16.1.0 (21 Nov 2020)
  - Guard `process` dependency behind an on by default flag.
    This allows one to shrink the dependency tree significantly
    by turning off the ability to use bash completion actions.
  - Remove `bytestring` dependency from the test suite.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Aug 13 2020 psimons@suse.com
- Update optparse-applicative to version 0.16.0.0.
  [#]# Version 0.16.0.0 (14 Aug 2020)
  - Add `Options.Applicative.NonEmpty.some1` function, which
    parses options the same as `some1` from base, but doesn't
    cause duplicates in the usage texts.
  - Further improve help text generation in the presence
    of optional values when nesting is involved, and many and
    some when displayed with a suffix.
  - Add "global" options to the usage texts for subcommands.
    When using subcommands, a "global options" section can
    now appear below the options and commands sections.
    Global options are *off* by default, to enable them, use
    the `helpShowGlobals` modifier.
    The `noGlobal` builder will suppress a single option being
    displayed in the global options list.
    Fixes issues:
  * \# 175 - List detailed subparser documentation with `--help`
  * \# 294 - Displaying global options when listing options for a command.
  * \# 359 - Subcommand help text lacks required parent command arguments
  - Allow the `--help` option to take the name of a command.
    Usage without any arguments is the same, but now, when an
    argument is given, if it is the name of a currently
    reachable command, the help text for that command will
    be show.
    Fixes issues:
  * \# 379 - cmd --help subcmd is not the same as cmd subcmd --help
  - Updated dependency bounds.
  - Add builder for the all positional parser policy.
  - Remove deprecated functions
  * nullOption
  * execParserMaybe
  * customExecParserMaybe
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu May  7 2020 Peter Simons <psimons@suse.com>
- Update Cabal file to get more accurate dependency information.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Sep 13 2019 psimons@suse.com
- Update optparse-applicative to version 0.15.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/optparse-applicative-0.15.1.0/src/CHANGELOG.md
* Sat Jul  6 2019 psimons@suse.com
- Update optparse-applicative to version 0.15.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/optparse-applicative-0.15.0.0/src/CHANGELOG.md
* Tue Jun 11 2019 Peter Simons <psimons@suse.com>
- Update Cabal file for more accurate build dependencies.
* Thu Oct  4 2018 psimons@suse.com
- Update optparse-applicative to version 0.14.3.0.
  [#]# Version 0.14.3.0 (03 Oct 2018)
  - Updated dependency bounds.
  - Fix tab completion with Commands being unreachable.
  - Clean ups and Documentation.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update optparse-applicative to version 0.14.2.0.
  - Export `HasName`, `HasCompleter`, `HasValue`, and
    `HasMetavar` type classes.
  - Upgrade `str` and related builders to be polymorphic over
    `IsString`. This allows `Text` and `Bytestring` to be used
    naturally with `strOption` and `strArgument` and friends.
  * Note:* This change may require additional type signatures
    in cases where the reader was necessary for type
    inference.
  - Export public API explicitly from `Options.Applicative`
    instead of re-exporting other modules.
  * Note:* Minor changes to exports were made in conjunction
    to this change. `ParserHelp` no longer requires an
    an extra import, and some internally used functions
    from `Options.Applicative.Common` are no longer
    exported from the main module.
  - Add Zsh and Fish completions with rich descriptions for
    options and commands.
    Use "--zsh-completion-script" and "fish-completion-script"
    to generate scripts for these shells.
  - Fix bash completions with quoted sections, tilde expansions
    and completions after "--".
  - Add suggestions to error message when a user mistypes a
    command or option.
  - Add `style` builder, for styling option descriptions.
  - Improve error message for options when a required argument
    is not supplied.
  - Fix #242 regarding flags with long options, where a flag given
    a long option could be interpreted incorrectly.
  - Fix `noIntersperse` to be more like its namesakes in other
    libraries. When on, options will be accepted until an argument
    is passed, after which all options will be treated as positional
    arguments.
  - Add `forwardOptions` builder, which will allow unknown options
    and flags to be passed to an argument builder.
    This is useful to mixed parsing environments, or wrappers to
    other commands.
  - Add `Semigroup` instances for `Completer` and `Chunk`.
  - Forwards compatibility with `MonadFail` proposal.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.13.2.0 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.13.1.0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.12.1.0 revision 0 with cabal2obs.
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 0.12.1.0
  * Improve subparser contexts to improve usage error texts
  * Fixed bugs
* Wed Dec 30 2015 mimi.vx@gmail.com
- update to 0.12.0.0
  * Add "missing" error condition descriptions when required flags and arguments
    are not provided.
  * Allow multiple short flags to be concatenated together behind a single
    hyphen, e.g. "-xcf".
  * Updated dependency bounds on process and ansi-wl-pprint.
  * Add Show and Eq instances to some types for easier debugging.
  * Add defaultPrefs, a default preferences value
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
